@@ -13,6 +13,7 @@ that some condition is met.
    ensureIsImage
 """
 
+import pathlib
 
 import nibabel as nib
 
@@ -22,7 +23,7 @@ import fsl.data.image as fslimage
 def ensureIsImage(img):
     """Ensures that the given ``img`` is an in-memory ``nibabel`` object.
     """
-    if isinstance(img, str):
+    if isinstance(img, (str, pathlib.Path)):
         img = fslimage.addExt(img)
         img = nib.load(img)
     return img
