@@ -154,12 +154,14 @@ def run(*args, **kwargs):
 
     :arg log:      Must be passed as a keyword argument.  Defaults to
                    ``{'tee' : True}``. An optional ``dict`` which may be used
-                   to redirect the command's standard output and error. The
-                   following keys are recognised:
+                   to redirect the command's standard output and error. Ignored
+                   if ``submit`` is specified. The following keys are
+                   recognised:
 
                      - tee:    If ``True`` (the default), the command's
                                standard output/error streams are forwarded to
-                               this processes streams.
+                               the output streams of this process, in addition
+                               to being captured and returned.
 
                      - stdout: Optional file-like object to which the command's
                                standard output stream can be forwarded.
@@ -167,12 +169,12 @@ def run(*args, **kwargs):
                      - stderr: Optional file-like object to which the command's
                                standard error stream can be forwarded.
 
-                     - cmd:    Optional file-like object to which the command
-                               itself is logged.
+                     - cmd:    Optional file-like or callable to which
+                               the command itself is logged.
 
     All other keyword arguments are passed through to the ``subprocess.Popen``
     object (via :func:`_realrun`), unless ``submit=True``, in which case they
-    are passed through to the :func:`.fslsub.submit` function.
+    are passed through to the :func:`.fsl_sub` function.
 
     :returns: If ``submit`` is provided, the ID of the submitted job is
               returned as a string. Otherwise returns a single value or a
@@ -200,10 +202,6 @@ def run(*args, **kwargs):
         submit = None
 
     if submit is not None:
-        returnStdout   = False
-        returnStderr   = False
-        returnExitcode = False
-
         if submit is True:
             submit = dict()
 
@@ -277,8 +275,8 @@ def _realrun(tee, logStdout, logStderr, logCmd, *args, **kwargs):
     :arg logStderr: Optional file-like object to which the command's standard
                     error stream can be forwarded.
 
-    :arg logCmd:    Optional file-like object to which the command itself is
-                    logged.
+    :arg logCmd:    Optional file-like or callable to which the command itself
+                    is logged.
 
     :arg args:      Command to run
 
@@ -321,9 +319,13 @@ def _realrun(tee, logStdout, logStderr, logCmd, *args, **kwargs):
             if logStdout is not None: outstreams.append(logStdout)
             if logStderr is not None: errstreams.append(logStderr)
 
-            # log the command if requested
-            if logCmd is not None:
-                cmd = ' '.join(args) + '\n'
+            # log the command if requested.
+            # logCmd can be a callable, or
+            # can be a file-like.
+            cmd = ' '.join(args) + '\n'
+            if callable(logCmd):
+                logCmd(cmd)
+            elif logCmd is not None:
                 if 'b' in getattr(logCmd, 'mode', 'w'):
                     logCmd.write(cmd.encode('utf-8'))
                 else:
