@@ -102,6 +102,7 @@ import                    logging
 import                    tempfile
 import                    warnings
 import                    functools
+import                    contextlib
 
 import nibabel as nib
 import numpy   as np
@@ -174,17 +175,23 @@ def genxwrapper(func, runner):
       - ``log``:      Passed to ``runner``. Defaults to ``{'tee':True}``.
       - ``cmdonly``:  Passed to ``runner``. Defaults to ``False``.
 
+    The default values for these arguments are stored in the
+    ``genxwrapper.run_options`` dictionary. This dictionary should not be
+    changed directly, but rather can be temporarily modified via the
+    :func:`wrapperconfig` context manager function.
+
     :arg func:   A function which generates a command line.
     :arg runner: Either :func:`.run.run` or :func:`.run.runfsl`.
     """
 
     def wrapper(*args, **kwargs):
-        stdout   = kwargs.pop('stdout',   True)
-        stderr   = kwargs.pop('stderr',   True)
-        exitcode = kwargs.pop('exitcode', False)
-        submit   = kwargs.pop('submit',   None)
-        cmdonly  = kwargs.pop('cmdonly',  False)
-        log      = kwargs.pop('log',      {'tee' : True})
+        opts     = genxwrapper.run_options
+        stdout   = kwargs.pop('stdout',   opts['stdout'])
+        stderr   = kwargs.pop('stderr',   opts['stderr'])
+        exitcode = kwargs.pop('exitcode', opts['exitcode'])
+        submit   = kwargs.pop('submit',   opts['submit'])
+        cmdonly  = kwargs.pop('cmdonly',  opts['cmdonly'])
+        logg     = kwargs.pop('log',      opts['log'])
 
         # many wrapper functions use fsl.utils.assertions
         # statements to check that input arguments are
@@ -196,7 +203,7 @@ def genxwrapper(func, runner):
 
         return runner(cmd,
                       stderr=stderr,
-                      log=log,
+                      log=logg,
                       submit=submit,
                       cmdonly=cmdonly,
                       stdout=stdout,
@@ -205,6 +212,16 @@ def genxwrapper(func, runner):
     return _update_wrapper(wrapper, func)
 
 
+genxwrapper.run_options = {
+    'stdout'   : True,
+    'stderr'   : True,
+    'exitcode' : False,
+    'submit'   : None,
+    'log'      : {'tee' : True},
+    'cmdonly'  : False
+}
+
+
 def cmdwrapper(func):
     """This decorator can be used on functions which generate a command line.
     It will pass the return value of the function to the
@@ -225,6 +242,23 @@ def fslwrapper(func):
     return genxwrapper(func, run.runfsl)
 
 
+@contextlib.contextmanager
+def wrapperconfig(**kwargs):
+    """Context manager to be used when calling wrapper functions. Can modify
+    the options/arguments that are passed to :func:`fsl.utils.run.run` when
+    calling a command from a wrapper function. For example::
+
+        with wrapperconfig(stdout=False):
+            bet('struct', 'struct_brain')
+    """
+    opts = dict(genxwrapper.run_options)
+    genxwrapper.run_options.update(kwargs)
+    try:
+        yield
+    finally:
+        genxwrapper.run_options = opts
+
+
 SHOW_IF_TRUE = object()
 """Constant to be used in the ``valmap`` passed to the :func:`applyArgStyle`
 function.
@@ -243,6 +277,21 @@ generated command line arguments.
 """
 
 
+EXPAND_LIST = object()
+"""Constant  to be used in the ``valmap`` passed to the :func:`applyArgStyle`
+function.
+
+``EXPAND_LIST`` argument values are expected to be sequences. Each element of
+the sequence will be added as a separate command line argument. For example::
+
+    applyArgStyle(argmap={'myarg' : EXPAND_LIST}, myarg=[1, 2, 3])
+
+will be transformed into::
+
+    --myarg 1 --myarg 2 --myarg 3
+"""
+
+
 def applyArgStyle(style=None,
                   valsep=None,
                   argmap=None,
@@ -263,7 +312,6 @@ def applyArgStyle(style=None,
     for single-character/short arguments) control how key-value pairs are
     converted into command-line options:
 
-
     =========  ==========  ===========================
     ``style``  ``valsep``  Result
     =========  ==========  ===========================
@@ -293,7 +341,10 @@ def applyArgStyle(style=None,
 
     :arg argmap:    Dictionary of ``{kwarg-name : cli-name}`` mappings. This be
                     used if you want to use different argument names in your
-                    Python function for the command-line options.
+                    Python function for the command-line options. ``argmap``
+                    may also be a callable - in this case, every argument name
+                    will be passed to it, and its return value used as the
+                    command-line option.
 
     :arg valmap:    Dictionary of ``{cli-name : value}`` mappings. This can be
                     used to define specific semantics for some command-line
@@ -307,12 +358,18 @@ def applyArgStyle(style=None,
                        ``False`` in ``kwargs``, the command line option
                        will be added (without any arguments).
 
+                     - :data:`EXPAND_LIST` - The argument value is assumed to
+                       be a sequence - each element will be added as a separate
+                       command-line option.
+
                      - Any other constant value. If the argument is present
                        in ``kwargs``, its command-line option will be
                        added, with the constant value as its argument.
 
                     The argument for any options not specified in the
                     ``valmap`` will be converted into strings.
+                    The argument names used in ``valmap`` must be the names
+                    used *after* any rules in ``argmap`` are applied.
 
     :arg charstyle: Separate style specification for single-character
                     arguments. If ``style == '--='``, defaults to ``'-'``,
@@ -335,6 +392,9 @@ def applyArgStyle(style=None,
                  quoted string.
     """
 
+    if argmap is None: argmap = {}
+    if valmap is None: valmap = {}
+
     if style is None:
         style = '--='
 
@@ -370,8 +430,11 @@ def applyArgStyle(style=None,
         raise ValueError(f'Incompatible style {charstyle} '
                          'and valsep ({charsep})')
 
-    if argmap is None: argmap = {}
-    if valmap is None: valmap = {}
+    # apply argmap transform
+    def maparg(arg):
+        # argmap can either be a dictionary or a callable
+        if callable(argmap): return argmap(arg)
+        else:                return argmap.get(arg, arg)
 
     # Format the argument.
     def fmtarg(arg, style):
@@ -405,16 +468,19 @@ def applyArgStyle(style=None,
         if len(k) == 1: sty, sep = charstyle, charsep
         else:           sty, sep = style,     valsep
 
-        k    = argmap.get(k, k)
-        mapv = valmap.get(k, fmtval(v, sep))
+        k    = maparg(k)
+        mapv = valmap.get(k, None)
         k    = fmtarg(k, sty)
 
         if mapv in (SHOW_IF_TRUE, HIDE_IF_TRUE):
             if (mapv is SHOW_IF_TRUE and     v) or \
                (mapv is HIDE_IF_TRUE and not v):
                 args.append(k)
+        elif mapv == EXPAND_LIST:
+            for vi in v:
+                args.extend(fmtargval(k, fmtval(vi, sep), sty))
         else:
-            args.extend(fmtargval(k, mapv, sty))
+            args.extend(fmtargval(k, fmtval(v, sep), sty))
 
     return args
 
@@ -428,16 +494,6 @@ def namedPositionals(func, args):
     :arg args: Tuple of positional arguments to be passed to ``func``.
     """
 
-    # Current implementation will
-    # result in naming collisions
-    # for something like this:
-    #
-    # def func(args0, *args):
-    #     ...
-    # because of automatic vararg
-    # naming. But who would write
-    # a function like that anyway?
-
     # Remove any decorators
     # from the function
     func = _unwrap(func)
@@ -466,12 +522,14 @@ def namedPositionals(func, args):
     # that are being passed in
     argnames = argnames[:len(args)]
 
-    # make up names for varargs
+    # generate names for varargs
     nvarargs = len(args) - len(argnames)
+    suffix   = namedPositionals.varargsSuffix
     if varargs is not None and nvarargs > 0:
-        argnames += ['{}{}'.format(varargs, i) for i in range(nvarargs)]
+        argnames += [f'{varargs}{i}{suffix}' for i in range(nvarargs)]
 
     return argnames
+namedPositionals.varargsSuffix = '_VARARG'
 
 
 LOAD = object()
@@ -709,6 +767,7 @@ class FileOrThing:
 
           - The argument value that was passed in
         """
+
         self.__func      = func
         self.__prepIn    = prepIn
         self.__prepOut   = prepOut
@@ -813,17 +872,20 @@ class FileOrThing:
         passed to the ``prepOut`` function specified at :meth:`__init__`.
         All other arguments are passed through the ``prepIn`` function.
 
-        :arg parent:  ``True`` if this ``FileOrThing`` is the first in a
-                      chain of ``FileOrThing`` decorators.
+        :arg parent:   ``True`` if this ``FileOrThing`` is the first in a
+                       chain of ``FileOrThing`` decorators.
 
-        :arg workdir: Directory in which all temporary files should be stored.
+        :arg workdir:  Directory in which all temporary files should be stored.
 
-        :arg args:    Positional arguments to be passed to the decorated
-                      function.
+        :arg argnames: Names for each positional argument.
 
-        :arg kwargs:  Keyword arguments to be passed to the decorated function.
+        :arg args:     Positional arguments to be passed to the decorated
+                       function.
 
-        :returns:     A tuple containing:
+        :arg kwargs:   Keyword arguments to be passed to the decorated
+                       function.
+
+        :returns:      A tuple containing:
 
                         - An updated copy of ``args``.
 
@@ -873,6 +935,8 @@ class FileOrThing:
         # accept an output prefix which contains
         # a directory path.
         if prefix is not None:
+            if isinstance(prefix, pathlib.Path):
+                prefix = op.abspath(prefix)
 
             # If prefix is set to LOAD,
             # all generated output files
@@ -917,7 +981,9 @@ class FileOrThing:
             isprefixed = (prefix is not None and
                           name.startswith(prefix))
 
-            if not (isprefixed or name in things):
+            if not any((isprefixed,
+                        name in things,
+                        name.endswith(namedPositionals.varargsSuffix))):
                 continue
 
             # Prefixed output files may only
@@ -965,6 +1031,15 @@ class FileOrThing:
         if realPrefix is not None and len(prefixedFiles) == 0:
             allargs[self.__outprefix] = realPrefix
 
+        # Turn any Path objects into absolute path
+        # strings. Don't use Path.resolve(), as it
+        # returns a relative path for non-existent
+        # files/dirs on Windows/certain Python
+        # versions.
+        for k, v in allargs.items():
+            if isinstance(v, pathlib.Path):
+                allargs[k] = op.abspath(v)
+
         args   = [allargs.pop(k) for k in argnames]
         kwargs = allargs
 
