@@ -318,6 +318,7 @@ def _test_Image_atts(imgtype):
             path = op.abspath(op.join(testdir, path))
             i    = fslimage.Image(path)
 
+            assert       i.editable
             assert not   i.iscomplex
             assert tuple(i.shape)                       == tuple(expdims)
             assert tuple(i.data.shape)                  == tuple(expdims)
@@ -550,7 +551,8 @@ def test_defaultImageType():
             else:
                 exptype = nib.Nifti2Image
 
-            img = fslimage.Image(np.random.randint(1, 10, (30, 30, 30)))
+            data = np.random.randint(1, 10, (30, 30, 30), dtype=np.int32)
+            img  = fslimage.Image(data)
 
             assert type(img.nibImage) == exptype
 
@@ -1546,3 +1548,17 @@ def test_adjust():
         imgb = affine.axisBounds(img.shape, img.voxToWorldMat)
         adjb = affine.axisBounds(adj.shape, adj.voxToWorldMat)
         assert np.all(np.isclose(imgb, adjb, rtol=1e-5, atol=1e-5))
+
+
+def test_strval():
+    tests = [
+        (b'abcde\x13\xf7fgh\0', 'abcdefgh'),
+        (b'abcde\0fghij\0',     'abcde'),
+    ]
+    with tempdir():
+        for aux_file, expect in tests:
+            i = make_image('image.nii', dims=(10, 10, 10), pixdims=(1, 1, 1))
+            i.header['aux_file'] = aux_file
+            i.to_filename('image.nii')
+            i = fslimage.Image('image.nii')
+            assert i.strval('aux_file') == expect
