@@ -10,6 +10,7 @@ import            os
 import            shlex
 import            pathlib
 import            textwrap
+import functools as ft
 
 from unittest import mock
 
@@ -149,7 +150,7 @@ def test_applyArgStyle_argmap():
     assert wutils.applyArgStyle('-', argmap=argmap, **kwargs) in exp
 
 
-def test_applyArgStyle_valmap():
+def test_applyArgStyle_valmap_show_hide():
 
     valmap = {
         'a' : wutils.SHOW_IF_TRUE,
@@ -176,6 +177,27 @@ def test_applyArgStyle_valmap():
         assert wutils.applyArgStyle('-', valmap=valmap, **kwargs) in expected
 
 
+def test_applyArgStyle_valmap_unroll_list():
+
+    valmap = {
+        'a'  : wutils.EXPAND_LIST,
+        'aa' : wutils.EXPAND_LIST,
+    }
+
+    tests = [
+        ({ 'a' : [1, 2, 3], 'b' : [1, 2, 3]},
+         '-a 1 -a 2 -a 3 -b 1 2 3'),
+
+        ({ 'aa' : [1, 2, 3], 'bb' : [1, 2, 3]},
+         '--aa=1 --aa=2 --aa=3 --bb=1,2,3'),
+    ]
+
+    for kwargs, expected in tests:
+        expected = shlex.split(expected)
+        assert wutils.applyArgStyle(valmap=valmap, **kwargs) == expected
+
+
+
 def test_applyArgStyle_argmap_valmap():
 
     argmap = {'a1' : 'a', 'a2' : 'b'}
@@ -186,23 +208,39 @@ def test_applyArgStyle_argmap_valmap():
 
     # kwargs, expected
     tests = [
-        ({                            }, ['']),
-        ({ 'a1' : False,              }, ['']),
-        ({ 'a1' : True,               }, ['-a']),
-        ({               'a2' : False }, ['-b']),
-        ({               'a2' : True  }, ['']),
-        ({ 'a1' : False, 'a2' : True  }, ['']),
-        ({ 'a1' : True,  'a2' : True  }, ['-a']),
-        ({ 'a1' : False, 'a2' : False }, ['-b']),
-        ({ 'a1' : False, 'a2' : True  }, ['']),
-        ({ 'a1' : True,  'a2' : False }, ['-a -b', '-b -a']),
-        ({ 'a1' : True,  'a2' : True  }, ['-a']),
+        ({                            }, ''),
+        ({ 'a1' : False,              }, ''),
+        ({ 'a1' : True,               }, '-a'),
+        ({               'a2' : False }, '-b'),
+        ({               'a2' : True  }, ''),
+        ({ 'a1' : False, 'a2' : True  }, ''),
+        ({ 'a1' : True,  'a2' : True  }, '-a'),
+        ({ 'a1' : False, 'a2' : False }, '-b'),
+        ({ 'a1' : False, 'a2' : True  }, ''),
+        ({ 'a1' : True,  'a2' : False }, '-a -b'),
+        ({ 'a1' : True,  'a2' : True  }, '-a'),
     ]
 
     for kwargs, expected in tests:
-        expected = [shlex.split(e) for e in expected]
+        expected = shlex.split(expected)
         assert wutils.applyArgStyle(
-            '-', argmap=argmap, valmap=valmap, **kwargs) in expected
+            '-', argmap=argmap, valmap=valmap, **kwargs) == expected
+
+
+def test_applyArgStyle_callable_argmap():
+
+    def repl(s):
+        return s.replace('_', '-')
+
+    tests = [
+        ({'some_arg' : 'a_b_c', 'c' : 'd_e'},
+         ['--some-arg=a_b_c', '-c', 'd_e']),
+        ({'some_arg' : 'a', 'somearg' : 'b', 'c' : 'd'},
+         ['--some-arg=a', '--somearg=b', '-c', 'd']),
+    ]
+
+    for kwargs, expect in tests:
+        assert wutils.applyArgStyle(argmap=repl, **kwargs) == expect
 
 
 def test_namedPositionals():
@@ -214,14 +252,15 @@ def test_namedPositionals():
     def func6(a, b, *args): pass
     def func7(a, b, *args, **kwargs): pass
 
+    suf   = wutils.namedPositionals.varargsSuffix
     tests = [
         (func1, [],        []),
         (func2, [1, 2, 3], ['a', 'b', 'c']),
         (func3, [1, 2, 3], ['a', 'b', 'c']),
-        (func4, [1, 2, 3], ['args0', 'args1', 'args2']),
-        (func5, [1, 2, 3], ['args0', 'args1', 'args2']),
-        (func6, [1, 2, 3], ['a', 'b', 'args0']),
-        (func7, [1, 2, 3], ['a', 'b', 'args0']),
+        (func4, [1, 2, 3], [f'args0{suf}', f'args1{suf}', f'args2{suf}']),
+        (func5, [1, 2, 3], [f'args0{suf}', f'args1{suf}', f'args2{suf}']),
+        (func6, [1, 2, 3], ['a', 'b', f'args0{suf}']),
+        (func7, [1, 2, 3], ['a', 'b', f'args0{suf}']),
     ]
 
     for func, args, expected in tests:
@@ -293,10 +332,13 @@ def test_fileOrImage():
 
     with tempdir.tempdir():
 
-        img1     = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]]), np.eye(4))
-        img2     = nib.nifti1.Nifti1Image(np.array([[5,  6], [ 7,  8]]), np.eye(4))
-        img3     = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]]), np.eye(4))
-        expected = np.array([[5, 12], [21, 32]])
+        img1     = nib.nifti1.Nifti1Image(
+            np.array([[1,  2], [ 3,  4]], dtype=np.int32), np.eye(4))
+        img2     = nib.nifti1.Nifti1Image(
+            np.array([[5,  6], [ 7,  8]], dtype=np.int32), np.eye(4))
+        img3     = nib.nifti1.Nifti1Image(
+            np.array([[1,  2], [ 3,  4]], dtype=np.int32), np.eye(4))
+        expected = np.array([[5, 12], [21, 32]], dtype=np.int32)
         nib.save(img1, 'img1.nii')
         nib.save(img2, 'img2.nii')
 
@@ -408,6 +450,29 @@ def test_fileOrThing_sequence():
         assert np.all(func(infiles[0], wutils.LOAD)['out'] == inputs[0])
 
 
+def test_fileOrThing_var_positionals():
+
+    @wutils.fileOrArray('output', 'inputs')
+    def func(output, *inputs):
+
+        ins = [np.loadtxt(i) for i in inputs]
+        res  = np.sum(ins, axis=0)
+
+        np.savetxt(output, res)
+
+    inputs  = [np.random.randint(1, 10, (3, 3)) for i in range(4)]
+    infiles = ['input{}.txt'.format(i) for i in range(len(inputs))]
+    exp     = np.sum(inputs, axis=0)
+
+    with tempdir.tempdir():
+
+        for ifile, idata in zip(infiles, inputs):
+            np.savetxt(ifile, idata)
+
+        func('result.txt', *inputs)
+        assert np.all(np.loadtxt('result.txt') == exp)
+
+
 def test_fileOrText():
 
     @wutils.fileOrText('input', 'output')
@@ -446,7 +511,8 @@ def test_fileOrThing_outprefix():
 
 
     with tempdir.tempdir() as td:
-        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]]), np.eye(4))
+        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                      np.eye(4))
         exp1 = np.asanyarray(img.dataobj) * 5
         exp2 = np.asanyarray(img.dataobj) * 10
         nib.save(img, 'img.nii')
@@ -475,6 +541,46 @@ def test_fileOrThing_outprefix():
         cleardir(td, 'myout*')
 
 
+def test_fileOrThing_pathlib():
+    @wutils.fileOrImage('img', 'out')
+    def basefunc(img, out):
+        img    = np.asanyarray(nib.load(img).dataobj)
+        outimg = nib.nifti1.Nifti1Image(img * 5,  np.eye(4))
+        nib.save(outimg, out)
+
+    with tempdir.tempdir() as td:
+        img = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                     np.eye(4))
+        exp = np.asanyarray(img.dataobj) * 5
+        nib.save(img, 'img.nii')
+
+        basefunc(pathlib.Path('img.nii'), pathlib.Path('output.nii'))
+        assert np.all(np.asanyarray(nib.load('output.nii') .dataobj) == exp)
+
+
+def test_fileOrThing_outprefix_pathlib():
+    @wutils.fileOrImage('img', outprefix='output_base')
+    def basefunc(img, output_base):
+        img = np.asanyarray(nib.load(img).dataobj)
+
+        out1 = nib.nifti1.Nifti1Image(img * 5,  np.eye(4))
+        out2 = nib.nifti1.Nifti1Image(img * 10, np.eye(4))
+
+        nib.save(out1, '{}_times5.nii.gz' .format(output_base))
+        nib.save(out2, '{}_times10.nii.gz'.format(output_base))
+
+    with tempdir.tempdir() as td:
+        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                      np.eye(4))
+        exp1 = np.asanyarray(img.dataobj) * 5
+        exp2 = np.asanyarray(img.dataobj) * 10
+        nib.save(img, 'img.nii')
+
+        basefunc(pathlib.Path('img.nii'), pathlib.Path('myout'))
+        assert np.all(np.asanyarray(nib.load('myout_times5.nii.gz') .dataobj) == exp1)
+        assert np.all(np.asanyarray(nib.load('myout_times10.nii.gz').dataobj) == exp2)
+
+
 def test_fileOrThing_outprefix_differentTypes():
 
     @wutils.fileOrImage('img', outprefix='outpref')
@@ -490,7 +596,8 @@ def test_fileOrThing_outprefix_differentTypes():
             f.write(text)
 
     with tempdir.tempdir() as td:
-        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]]), np.eye(4))
+        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                      np.eye(4))
         expi = np.asanyarray(img.dataobj) * 2
         expt = '1234567890'
 
@@ -535,7 +642,8 @@ def test_fileOrThing_outprefix_directory():
         nib.save(img4, op.join(outdir, 'img4.nii.gz'))
 
     with tempdir.tempdir() as td:
-        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]]), np.eye(4))
+        img  = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                      np.eye(4))
         exp2 = np.asanyarray(img.dataobj) * 2
         exp4 = np.asanyarray(img.dataobj) * 4
 
@@ -692,7 +800,8 @@ def test_chained_fileOrImageAndArray():
         np.savetxt(outarray, array * 2)
         outimg.to_filename(outimage)
 
-    image = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]]), np.eye(4))
+    image = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]], dtype=np.int32),
+                                   np.eye(4))
     array = np.array([[5, 6, 7, 8]])
 
     expimg = nib.nifti1.Nifti1Image(np.asanyarray(image.dataobj) * 2, np.eye(4))
@@ -751,7 +860,8 @@ def test_fileOrThing_chained_outprefix():
         np.savetxt('{}_array.txt'.format(out), outarr)
         outimg.to_filename('{}_image.nii'.format(out))
 
-    image = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]]), np.eye(4))
+    image = nib.nifti1.Nifti1Image(np.array([[1,  2], [ 3,  4]], dtype=np.int32),
+                                   np.eye(4))
     array = np.array([[5, 6, 7, 8]])
 
     expimg = nib.nifti1.Nifti1Image(np.asanyarray(image.dataobj) * 2, np.eye(4))
@@ -784,7 +894,8 @@ def test_fileOrThing_submit_cmdonly():
         nib.save(img, output)
 
     with tempdir.tempdir() as td:
-        img = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]]), np.eye(4))
+        img = nib.nifti1.Nifti1Image(np.array([[1, 2], [3, 4]], dtype=np.int32),
+                                     np.eye(4))
         exp = np.asanyarray(img.dataobj) * 2
         nib.save(img, 'input.nii.gz')
 
@@ -963,7 +1074,7 @@ def test_fileOrImage_all_tempfiles_cleared():
         i = nib.Nifti1Image(i.get_fdata() + 1, np.eye(4))
         i.to_filename(out)
 
-    arr    = np.array([[1, 2], [ 3, 4]])
+    arr    = np.array([[1, 2], [ 3, 4]], dtype=np.int32)
     img    = nib.nifti1.Nifti1Image(arr, np.eye(4))
     imgout = image(img, wutils.LOAD).out
 
